summaryrefslogtreecommitdiffstats
path: root/lib/interfaces/extensions
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2014-05-25 15:37:31 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2014-05-25 15:37:31 +0900
commit6392f5a9dfce2bf83617d49bb7f332181ec6004e (patch)
treeab69e390f7962b7e7dda1a3a64f035c61c751cf4 /lib/interfaces/extensions
parentaba2788b428dc53243407902e9ccbb20b97a69fd (diff)
downloadtdevelop-6392f5a9dfce2bf83617d49bb7f332181ec6004e.tar.gz
tdevelop-6392f5a9dfce2bf83617d49bb7f332181ec6004e.zip
Revert "Finish renaming tdevelop components"
This reverts commit 722ce1efbac31c61b1d4b13f7e075c9f311e3e73.
Diffstat (limited to 'lib/interfaces/extensions')
-rw-r--r--lib/interfaces/extensions/CMakeLists.txt20
-rw-r--r--lib/interfaces/extensions/Mainpage.dox10
-rw-r--r--lib/interfaces/extensions/Makefile.am18
-rw-r--r--lib/interfaces/extensions/codebrowserfrontend.h8
-rw-r--r--lib/interfaces/extensions/dcop/CMakeLists.txt10
-rw-r--r--lib/interfaces/extensions/dcop/KDevAppFrontendIface.cpp (renamed from lib/interfaces/extensions/dcop/TDevAppFrontendIface.cpp)26
-rw-r--r--lib/interfaces/extensions/dcop/KDevAppFrontendIface.h (renamed from lib/interfaces/extensions/dcop/TDevAppFrontendIface.h)14
-rw-r--r--lib/interfaces/extensions/dcop/KDevMakeFrontendIface.cpp (renamed from lib/interfaces/extensions/dcop/TDevMakeFrontendIface.cpp)14
-rw-r--r--lib/interfaces/extensions/dcop/KDevMakeFrontendIface.h (renamed from lib/interfaces/extensions/dcop/TDevMakeFrontendIface.h)14
-rw-r--r--lib/interfaces/extensions/dcop/Makefile.am10
-rw-r--r--lib/interfaces/extensions/kdevappfrontend.cpp2
-rw-r--r--lib/interfaces/extensions/kdevappfrontend.h (renamed from lib/interfaces/extensions/tdevappfrontend.h)20
-rw-r--r--lib/interfaces/extensions/kdevcreatefile.h (renamed from lib/interfaces/extensions/tdevcreatefile.h)22
-rw-r--r--lib/interfaces/extensions/kdevdifffrontend.cpp (renamed from lib/interfaces/extensions/tdevdifffrontend.cpp)10
-rw-r--r--lib/interfaces/extensions/kdevdifffrontend.h (renamed from lib/interfaces/extensions/tdevdifffrontend.h)20
-rw-r--r--lib/interfaces/extensions/kdevmakefrontend.cpp2
-rw-r--r--lib/interfaces/extensions/kdevmakefrontend.h (renamed from lib/interfaces/extensions/tdevmakefrontend.h)20
-rw-r--r--lib/interfaces/extensions/kdevquickopen.h (renamed from lib/interfaces/extensions/tdevquickopen.h)36
-rw-r--r--lib/interfaces/extensions/kdevsourceformatter.h (renamed from lib/interfaces/extensions/tdevsourceformatter.h)18
-rw-r--r--lib/interfaces/extensions/kdevversioncontrol.h (renamed from lib/interfaces/extensions/tdevversioncontrol.h)36
-rw-r--r--lib/interfaces/extensions/tdevappfrontend.cpp2
-rw-r--r--lib/interfaces/extensions/tdevmakefrontend.cpp2
22 files changed, 167 insertions, 167 deletions
diff --git a/lib/interfaces/extensions/CMakeLists.txt b/lib/interfaces/extensions/CMakeLists.txt
index cf5514be..459c1197 100644
--- a/lib/interfaces/extensions/CMakeLists.txt
+++ b/lib/interfaces/extensions/CMakeLists.txt
@@ -22,9 +22,9 @@ include_directories(
##### headers ###################################
install( FILES
- codebrowserfrontend.h tdevappfrontend.h tdevcreatefile.h
- tdevdifffrontend.h tdevmakefrontend.h tdevquickopen.h
- tdevsourceformatter.h tdevversioncontrol.h
+ codebrowserfrontend.h kdevappfrontend.h kdevcreatefile.h
+ kdevdifffrontend.h kdevmakefrontend.h kdevquickopen.h
+ kdevsourceformatter.h kdevversioncontrol.h
DESTINATION ${INCLUDE_INSTALL_DIR}/tdevelop/interfaces/extensions )
install( FILES
@@ -35,20 +35,20 @@ install( FILES
DESTINATION ${SERVICETYPES_INSTALL_DIR} )
-##### tdevextensions (static) ###################
+##### kdevextensions (static) ###################
add_custom_command( OUTPUT codebrowserfrontend.moc.cpp
COMMAND
${TMOC_EXECUTABLE} ${CMAKE_CURRENT_SOURCE_DIR}/codebrowserfrontend.h -o codebrowserfrontend.moc.cpp
DEPENDS ${CMAKE_CURRENT_SOURCE_DIR}/codebrowserfrontend.h )
-add_custom_command( OUTPUT tdevversioncontrol.moc.cpp
+add_custom_command( OUTPUT kdevversioncontrol.moc.cpp
COMMAND
- ${TMOC_EXECUTABLE} ${CMAKE_CURRENT_SOURCE_DIR}/tdevversioncontrol.h -o tdevversioncontrol.moc.cpp
- DEPENDS ${CMAKE_CURRENT_SOURCE_DIR}/tdevversioncontrol.h )
+ ${TMOC_EXECUTABLE} ${CMAKE_CURRENT_SOURCE_DIR}/kdevversioncontrol.h -o kdevversioncontrol.moc.cpp
+ DEPENDS ${CMAKE_CURRENT_SOURCE_DIR}/kdevversioncontrol.h )
-tde_add_library( tdevextensions STATIC_PIC AUTOMOC
+tde_add_library( kdevextensions STATIC_PIC AUTOMOC
SOURCES
- tdevappfrontend.cpp tdevappfrontend.cpp tdevmakefrontend.cpp
- codebrowserfrontend.moc.cpp tdevversioncontrol.moc.cpp
+ kdevappfrontend.cpp kdevappfrontend.cpp kdevmakefrontend.cpp
+ codebrowserfrontend.moc.cpp kdevversioncontrol.moc.cpp
)
diff --git a/lib/interfaces/extensions/Mainpage.dox b/lib/interfaces/extensions/Mainpage.dox
index 37c72c16..3b493fde 100644
--- a/lib/interfaces/extensions/Mainpage.dox
+++ b/lib/interfaces/extensions/Mainpage.dox
@@ -10,8 +10,8 @@ This library contains extension interfaces used by TDevelop plugin architecture.
\section whatisextension What is the TDevelop extension
Extension is a TDevelop plugin which implements one of extension interfaces.
-Extension is usually not important enough to be returned by @ref TDevApi and @ref TDevPlugin
-methods. Therefore extension instance can be obtained by @ref TDevPlugin::extension method.
+Extension is usually not important enough to be returned by @ref KDevApi and @ref KDevPlugin
+methods. Therefore extension instance can be obtained by @ref KDevPlugin::extension method.
Note: extension plugins can be either core, global and project plugins. They are loaded
in the same way other plugins are. But extensions differ from usual plugins.
@@ -36,10 +36,10 @@ those should be loaded at a time. This can be accomplished by:
@endcode
- Define an abstract base class for an extension like:
@code
- class KDevMyExtension: public TDevPlugin {
+ class KDevMyExtension: public KDevPlugin {
public:
- KDevMyExtension(const TDevPluginInfo *info, QObject* parent, const char* name)
- :TDevPlugin(info, parent, name) {}
+ KDevMyExtension(const KDevPluginInfo *info, QObject* parent, const char* name)
+ :KDevPlugin(info, parent, name) {}
virtual void doSomething() = 0;
};
diff --git a/lib/interfaces/extensions/Makefile.am b/lib/interfaces/extensions/Makefile.am
index 55f4d774..a6d00bc2 100644
--- a/lib/interfaces/extensions/Makefile.am
+++ b/lib/interfaces/extensions/Makefile.am
@@ -1,7 +1,7 @@
tdevelopincludeextdir = $(includedir)/tdevelop/interfaces/extensions
-tdevelopincludeext_HEADERS = codebrowserfrontend.h tdevappfrontend.h \
- tdevcreatefile.h tdevdifffrontend.h tdevmakefrontend.h tdevquickopen.h \
- tdevsourceformatter.h tdevversioncontrol.h
+tdevelopincludeext_HEADERS = codebrowserfrontend.h kdevappfrontend.h \
+ kdevcreatefile.h kdevdifffrontend.h kdevmakefrontend.h kdevquickopen.h \
+ kdevsourceformatter.h kdevversioncontrol.h
servicetypedir = $(kde_servicetypesdir)
servicetype_DATA = tdevelopappfrontend.desktop \
@@ -10,14 +10,14 @@ servicetype_DATA = tdevelopappfrontend.desktop \
tdevelopversioncontrol.desktop
SUBDIRS = dcop
-libtdevextensions_la_LDFLAGS = $(all_libraries)
-noinst_LTLIBRARIES = libtdevextensions.la
-libtdevextensions_la_SOURCES = tdevappfrontend.cpp tdevmakefrontend.cpp
+libkdevextensions_la_LDFLAGS = $(all_libraries)
+noinst_LTLIBRARIES = libkdevextensions.la
+libkdevextensions_la_SOURCES = kdevappfrontend.cpp kdevmakefrontend.cpp
INCLUDES = -I$(top_srcdir)/lib/interfaces $(all_includes)
METASOURCES = AUTO
-DOXYGEN_REFERENCES = dcop interfaces tdecore tdefx tdeui tdehtml tdemdi tdeio kjs tdeparts tdeutils tdevinterfaces
-DOXYGEN_PROJECTNAME = TDevelop Extension Interfaces Library
-DOXYGEN_DOCDIRPREFIX = tdev
+DOXYGEN_REFERENCES = dcop interfaces tdecore tdefx tdeui tdehtml tdemdi tdeio kjs tdeparts tdeutils kdevinterfaces
+DOXYGEN_PROJECTNAME = KDevelop Extension Interfaces Library
+DOXYGEN_DOCDIRPREFIX = kdev
include ../../../Doxyfile.am
noinst_HEADERS = codebrowserfrontend.h
diff --git a/lib/interfaces/extensions/codebrowserfrontend.h b/lib/interfaces/extensions/codebrowserfrontend.h
index 68c4e90f..e8158fe4 100644
--- a/lib/interfaces/extensions/codebrowserfrontend.h
+++ b/lib/interfaces/extensions/codebrowserfrontend.h
@@ -20,18 +20,18 @@
#define CODEBROWSERRONTEND_H
-#include <tdevplugin.h>
+#include <kdevplugin.h>
#include <codemodel.h>
namespace Extensions {
-class TDevCodeBrowserFrontend : public TDevPlugin {
+class KDevCodeBrowserFrontend : public KDevPlugin {
Q_OBJECT
public:
- TDevCodeBrowserFrontend(const TDevPluginInfo *info, TQObject *parent=0, const char *name=0 )
- :TDevPlugin(info, parent, name ? name : "CodeBrowserFrontend") {}
+ KDevCodeBrowserFrontend(const KDevPluginInfo *info, TQObject *parent=0, const char *name=0 )
+ :KDevPlugin(info, parent, name ? name : "CodeBrowserFrontend") {}
///Used by the quickopen-plugin to notify extensions that it jumped to a searched item
virtual bool jumpedToItem( ItemDom item ) = 0;
diff --git a/lib/interfaces/extensions/dcop/CMakeLists.txt b/lib/interfaces/extensions/dcop/CMakeLists.txt
index 8658d320..b6255fc6 100644
--- a/lib/interfaces/extensions/dcop/CMakeLists.txt
+++ b/lib/interfaces/extensions/dcop/CMakeLists.txt
@@ -21,14 +21,14 @@ include_directories(
##### headers ###################################
install( FILES
- TDevAppFrontendIface.h TDevMakeFrontendIface.h
+ KDevAppFrontendIface.h KDevMakeFrontendIface.h
DESTINATION ${INCLUDE_INSTALL_DIR}/tdevelop/interfaces/extensions/dcop )
-##### tdevdcopextensions (static) ###############
+##### kdevdcopextensions (static) ###############
-tde_add_library( tdevdcopextensions STATIC_PIC
+tde_add_library( kdevdcopextensions STATIC_PIC
SOURCES
- TDevAppFrontendIface.cpp TDevMakeFrontendIface.cpp
- TDevAppFrontendIface.skel TDevMakeFrontendIface.skel
+ KDevAppFrontendIface.cpp KDevMakeFrontendIface.cpp
+ KDevAppFrontendIface.skel KDevMakeFrontendIface.skel
)
diff --git a/lib/interfaces/extensions/dcop/TDevAppFrontendIface.cpp b/lib/interfaces/extensions/dcop/KDevAppFrontendIface.cpp
index a42d0d7d..1eca4bfc 100644
--- a/lib/interfaces/extensions/dcop/TDevAppFrontendIface.cpp
+++ b/lib/interfaces/extensions/dcop/KDevAppFrontendIface.cpp
@@ -21,56 +21,56 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#include "TDevAppFrontendIface.h"
-#include "tdevappfrontend.h"
+#include "KDevAppFrontendIface.h"
+#include "kdevappfrontend.h"
-TDevAppFrontendIface::TDevAppFrontendIface(TDevAppFrontend *appFrontend)
- : DCOPObject("TDevAppFrontend"), m_appFrontend(appFrontend)
+KDevAppFrontendIface::KDevAppFrontendIface(KDevAppFrontend *appFrontend)
+ : DCOPObject("KDevAppFrontend"), m_appFrontend(appFrontend)
{
}
-TDevAppFrontendIface::~TDevAppFrontendIface()
+KDevAppFrontendIface::~KDevAppFrontendIface()
{}
-void TDevAppFrontendIface::startAppCommand(const TQString &directory, const TQString &command, bool inTerminal)
+void KDevAppFrontendIface::startAppCommand(const TQString &directory, const TQString &command, bool inTerminal)
{
m_appFrontend->startAppCommand(directory, command, inTerminal);
}
-void TDevAppFrontendIface::stopApplication( )
+void KDevAppFrontendIface::stopApplication( )
{
m_appFrontend->stopApplication();
}
-bool TDevAppFrontendIface::isRunning( )
+bool KDevAppFrontendIface::isRunning( )
{
return m_appFrontend->isRunning();
}
-void TDevAppFrontendIface::clearView( )
+void KDevAppFrontendIface::clearView( )
{
m_appFrontend->clearView();
}
-void TDevAppFrontendIface::insertStderrLine( const TQCString & line )
+void KDevAppFrontendIface::insertStderrLine( const TQCString & line )
{
m_appFrontend->insertStderrLine(line);
}
-void TDevAppFrontendIface::insertStdoutLine( const TQCString & line )
+void KDevAppFrontendIface::insertStdoutLine( const TQCString & line )
{
m_appFrontend->insertStdoutLine(line);
}
-void TDevAppFrontendIface::addPartialStderrLine( const TQCString& line )
+void KDevAppFrontendIface::addPartialStderrLine( const TQCString& line )
{
m_appFrontend->addPartialStderrLine(line);
}
-void TDevAppFrontendIface::addPartialStdoutLine( const TQCString& line )
+void KDevAppFrontendIface::addPartialStdoutLine( const TQCString& line )
{
m_appFrontend->addPartialStdoutLine(line);
}
diff --git a/lib/interfaces/extensions/dcop/TDevAppFrontendIface.h b/lib/interfaces/extensions/dcop/KDevAppFrontendIface.h
index 5061c782..3903e897 100644
--- a/lib/interfaces/extensions/dcop/TDevAppFrontendIface.h
+++ b/lib/interfaces/extensions/dcop/KDevAppFrontendIface.h
@@ -19,21 +19,21 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef _TDEVAPPFRONTENDIFACE_H_
-#define _TDEVAPPFRONTENDIFACE_H_
+#ifndef _KDEVAPPFRONTENDIFACE_H_
+#define _KDEVAPPFRONTENDIFACE_H_
#include <dcopobject.h>
-class TDevAppFrontend;
+class KDevAppFrontend;
-class TDevAppFrontendIface : public DCOPObject
+class KDevAppFrontendIface : public DCOPObject
{
K_DCOP
public:
- TDevAppFrontendIface( TDevAppFrontend *appFrontend );
- ~TDevAppFrontendIface();
+ KDevAppFrontendIface( KDevAppFrontend *appFrontend );
+ ~KDevAppFrontendIface();
k_dcop:
void startAppCommand(const TQString &directory, const TQString &command, bool inTerminal);
@@ -46,7 +46,7 @@ k_dcop:
void addPartialStdoutLine(const TQCString &line);
private:
- TDevAppFrontend *m_appFrontend;
+ KDevAppFrontend *m_appFrontend;
};
#endif
diff --git a/lib/interfaces/extensions/dcop/TDevMakeFrontendIface.cpp b/lib/interfaces/extensions/dcop/KDevMakeFrontendIface.cpp
index 06bd432f..73305e4a 100644
--- a/lib/interfaces/extensions/dcop/TDevMakeFrontendIface.cpp
+++ b/lib/interfaces/extensions/dcop/KDevMakeFrontendIface.cpp
@@ -20,27 +20,27 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#include "TDevMakeFrontendIface.h"
-#include "tdevmakefrontend.h"
+#include "KDevMakeFrontendIface.h"
+#include "kdevmakefrontend.h"
-TDevMakeFrontendIface::TDevMakeFrontendIface(TDevMakeFrontend *makeFrontend)
- : DCOPObject("TDevMakeFrontend")
+KDevMakeFrontendIface::KDevMakeFrontendIface(KDevMakeFrontend *makeFrontend)
+ : DCOPObject("KDevMakeFrontend")
{
m_makeFrontend = makeFrontend;
}
-TDevMakeFrontendIface::~TDevMakeFrontendIface()
+KDevMakeFrontendIface::~KDevMakeFrontendIface()
{}
-void TDevMakeFrontendIface::queueCommand(const TQString &dir, const TQString &command)
+void KDevMakeFrontendIface::queueCommand(const TQString &dir, const TQString &command)
{
m_makeFrontend->queueCommand(dir, command);
}
-bool TDevMakeFrontendIface::isRunning( )
+bool KDevMakeFrontendIface::isRunning( )
{
return m_makeFrontend->isRunning();
}
diff --git a/lib/interfaces/extensions/dcop/TDevMakeFrontendIface.h b/lib/interfaces/extensions/dcop/KDevMakeFrontendIface.h
index 3aee75be..53217359 100644
--- a/lib/interfaces/extensions/dcop/TDevMakeFrontendIface.h
+++ b/lib/interfaces/extensions/dcop/KDevMakeFrontendIface.h
@@ -18,28 +18,28 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef _TDEVMAKEFRONTENDIFACE_H_
-#define _TDEVMAKEFRONTENDIFACE_H_
+#ifndef _KDEVMAKEFRONTENDIFACE_H_
+#define _KDEVMAKEFRONTENDIFACE_H_
#include <dcopobject.h>
-class TDevMakeFrontend;
+class KDevMakeFrontend;
-class TDevMakeFrontendIface : public DCOPObject
+class KDevMakeFrontendIface : public DCOPObject
{
K_DCOP
public:
- TDevMakeFrontendIface( TDevMakeFrontend *makeFrontend );
- ~TDevMakeFrontendIface();
+ KDevMakeFrontendIface( KDevMakeFrontend *makeFrontend );
+ ~KDevMakeFrontendIface();
k_dcop:
void queueCommand(const TQString &dir, const TQString &command);
bool isRunning();
private:
- TDevMakeFrontend *m_makeFrontend;
+ KDevMakeFrontend *m_makeFrontend;
};
#endif
diff --git a/lib/interfaces/extensions/dcop/Makefile.am b/lib/interfaces/extensions/dcop/Makefile.am
index e46606ac..116c4979 100644
--- a/lib/interfaces/extensions/dcop/Makefile.am
+++ b/lib/interfaces/extensions/dcop/Makefile.am
@@ -1,10 +1,10 @@
INCLUDES = -I$(top_srcdir)/lib/interfaces -I$(top_srcdir)/lib/interfaces/extensions $(all_includes)
METASOURCES = AUTO
-noinst_LTLIBRARIES = libtdevdcopextensions.la
-libtdevdcopextensions_la_LDFLAGS = $(all_libraries)
-libtdevdcopextensions_la_SOURCES = TDevAppFrontendIface.cpp \
- TDevMakeFrontendIface.cpp TDevAppFrontendIface.skel TDevMakeFrontendIface.skel
+noinst_LTLIBRARIES = libkdevdcopextensions.la
+libkdevdcopextensions_la_LDFLAGS = $(all_libraries)
+libkdevdcopextensions_la_SOURCES = KDevAppFrontendIface.cpp \
+ KDevMakeFrontendIface.cpp KDevAppFrontendIface.skel KDevMakeFrontendIface.skel
dcopincludeextdir = $(includedir)/tdevelop/interfaces/extensions/dcop
-dcopincludeext_HEADERS = TDevAppFrontendIface.h TDevMakeFrontendIface.h
+dcopincludeext_HEADERS = KDevAppFrontendIface.h KDevMakeFrontendIface.h
diff --git a/lib/interfaces/extensions/kdevappfrontend.cpp b/lib/interfaces/extensions/kdevappfrontend.cpp
new file mode 100644
index 00000000..3d918fe2
--- /dev/null
+++ b/lib/interfaces/extensions/kdevappfrontend.cpp
@@ -0,0 +1,2 @@
+#include "kdevappfrontend.h"
+#include "kdevappfrontend.moc"
diff --git a/lib/interfaces/extensions/tdevappfrontend.h b/lib/interfaces/extensions/kdevappfrontend.h
index 085d3c9d..76952f35 100644
--- a/lib/interfaces/extensions/tdevappfrontend.h
+++ b/lib/interfaces/extensions/kdevappfrontend.h
@@ -23,14 +23,14 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef TDEVAPPFRONTEND_H
-#define TDEVAPPFRONTEND_H
+#ifndef KDEVAPPFRONTEND_H
+#define KDEVAPPFRONTEND_H
#include <tqstringlist.h>
-#include <tdevplugin.h>
+#include <kdevplugin.h>
/**
-@file tdevappfrontend.h
+@file kdevappfrontend.h
Application frontend interface.
*/
@@ -45,16 +45,16 @@ Currently, this interface defines ways to do the following:
Instances that implement this interface are available through extension architecture:
@code
-TDevAppFrontend *apf = extension<TDevAppFrontend>("TDevelop/AppFrontend");
+KDevAppFrontend *apf = extension<KDevAppFrontend>("TDevelop/AppFrontend");
if (apf) {
// do something
} else {
// fail
}
@endcode
-@sa TDevPlugin::extension method documentation.
+@sa KDevPlugin::extension method documentation.
*/
-class TDevAppFrontend : public TDevPlugin
+class KDevAppFrontend : public KDevPlugin
{
Q_OBJECT
@@ -66,11 +66,11 @@ public:
plugin information in various places like "about application" dialog, plugin selector
dialog, etc. Plugin does not take ownership on info object, also its lifetime should
be equal to the lifetime of the plugin.
- @param parent The parent object for the plugin. Parent object must implement @ref TDevApi
+ @param parent The parent object for the plugin. Parent object must implement @ref KDevApi
interface. Otherwise the plugin will not be constructed.
@param name The internal name which identifies the plugin.*/
- TDevAppFrontend(const TDevPluginInfo *info, TQObject *parent=0, const char *name=0 )
- :TDevPlugin(info, parent, name ? name : "TDevAppFrontend") {}
+ KDevAppFrontend(const KDevPluginInfo *info, TQObject *parent=0, const char *name=0 )
+ :KDevPlugin(info, parent, name ? name : "KDevAppFrontend") {}
/**@return Whether the application is currently running.*/
virtual bool isRunning() = 0;
diff --git a/lib/interfaces/extensions/tdevdifffrontend.cpp b/lib/interfaces/extensions/kdevdifffrontend.cpp
index aa7e0b19..745703e4 100644
--- a/lib/interfaces/extensions/tdevdifffrontend.cpp
+++ b/lib/interfaces/extensions/kdevdifffrontend.cpp
@@ -18,16 +18,16 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#include "tdevdifffrontend.h"
+#include "kdevdifffrontend.h"
-TDevDiffFrontend::TDevDiffFrontend(const TDevPluginInfo *info, TQObject *parent, const char *name)
- : TDevPlugin(info, parent, name ? name : "TDevDiffFrontend")
+KDevDiffFrontend::KDevDiffFrontend(const KDevPluginInfo *info, TQObject *parent, const char *name)
+ : KDevPlugin(info, parent, name ? name : "KDevDiffFrontend")
{
}
-TDevDiffFrontend::~TDevDiffFrontend()
+KDevDiffFrontend::~KDevDiffFrontend()
{
}
-#include "tdevdifffrontend.moc"
+#include "kdevdifffrontend.moc"
diff --git a/lib/interfaces/extensions/tdevdifffrontend.h b/lib/interfaces/extensions/kdevdifffrontend.h
index c0c343cb..6d4cb2b6 100644
--- a/lib/interfaces/extensions/tdevdifffrontend.h
+++ b/lib/interfaces/extensions/kdevdifffrontend.h
@@ -18,14 +18,14 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef TDEVDIFFFRONTEND_H
-#define TDEVDIFFFRONTEND_H
+#ifndef KDEVDIFFFRONTEND_H
+#define KDEVDIFFFRONTEND_H
#include <kurl.h>
-#include <tdevplugin.h>
+#include <kdevplugin.h>
/**
-@file tdevdifffrontend.h
+@file kdevdifffrontend.h
Diff frontend interface.
*/
@@ -36,16 +36,16 @@ files.
Instances that implement this interface are available through extension architecture:
@code
-TDevDiffFrontend *df = extension<TDevDiffFrontend>("TDevelop/DiffFrontend");
+KDevDiffFrontend *df = extension<KDevDiffFrontend>("TDevelop/DiffFrontend");
if (df) {
// do something
} else {
// fail
}
@endcode
-@sa TDevPlugin::extension method documentation.
+@sa KDevPlugin::extension method documentation.
*/
-class TDevDiffFrontend : public TDevPlugin
+class KDevDiffFrontend : public KDevPlugin
{
public:
@@ -55,11 +55,11 @@ public:
plugin information in various places like "about application" dialog, plugin selector
dialog, etc. Plugin does not take ownership on info object, also its lifetime should
be equal to the lifetime of the plugin.
- @param parent The parent object for the plugin. Parent object must implement @ref TDevApi
+ @param parent The parent object for the plugin. Parent object must implement @ref KDevApi
interface. Otherwise the plugin will not be constructed.
@param name The internal name which identifies the plugin.*/
- TDevDiffFrontend( const TDevPluginInfo *info, TQObject *parent=0, const char *name=0 )
- :TDevPlugin(info, parent, name ? name : "TDevDiffFrontend") {}
+ KDevDiffFrontend( const KDevPluginInfo *info, TQObject *parent=0, const char *name=0 )
+ :KDevPlugin(info, parent, name ? name : "KDevDiffFrontend") {}
/**Displays the patch.
@param diff A string which contains a patch in unified format.*/
diff --git a/lib/interfaces/extensions/kdevmakefrontend.cpp b/lib/interfaces/extensions/kdevmakefrontend.cpp
new file mode 100644
index 00000000..5e035270
--- /dev/null
+++ b/lib/interfaces/extensions/kdevmakefrontend.cpp
@@ -0,0 +1,2 @@
+#include "kdevmakefrontend.h"
+#include "kdevmakefrontend.moc"
diff --git a/lib/interfaces/extensions/tdevmakefrontend.h b/lib/interfaces/extensions/kdevmakefrontend.h
index 47b14fc4..52afa3d3 100644
--- a/lib/interfaces/extensions/tdevmakefrontend.h
+++ b/lib/interfaces/extensions/kdevmakefrontend.h
@@ -23,14 +23,14 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef TDEVMAKEFRONTEND_H
-#define TDEVMAKEFRONTEND_H
+#ifndef KDEVMAKEFRONTEND_H
+#define KDEVMAKEFRONTEND_H
#include <tqstringlist.h>
-#include <tdevplugin.h>
+#include <kdevplugin.h>
/**
-@file tdevmakefrontend.h
+@file kdevmakefrontend.h
Make frontend interface.
*/
@@ -41,16 +41,16 @@ or similar commands to build a project, api documentation, etc.
Instances that implement this interface are available through extension architecture:
@code
-TDevMakeFrontend *mf = extension<TDevMakeFrontend>("TDevelop/MakeFrontend");
+KDevMakeFrontend *mf = extension<KDevMakeFrontend>("TDevelop/MakeFrontend");
if (mf) {
// do something
} else {
// fail
}
@endcode
-@sa TDevPlugin::extension method documentation.
+@sa KDevPlugin::extension method documentation.
*/
-class TDevMakeFrontend : public TDevPlugin
+class KDevMakeFrontend : public KDevPlugin
{
Q_OBJECT
@@ -63,11 +63,11 @@ public:
plugin information in various places like "about application" dialog, plugin selector
dialog, etc. Plugin does not take ownership on info object, also its lifetime should
be equal to the lifetime of the plugin.
- @param parent The parent object for the plugin. Parent object must implement @ref TDevApi
+ @param parent The parent object for the plugin. Parent object must implement @ref KDevApi
interface. Otherwise the plugin will not be constructed.
@param name The internal name which identifies the plugin.*/
- TDevMakeFrontend(const TDevPluginInfo *info, TQObject *parent=0, const char *name=0 )
- :TDevPlugin(info, parent, name ? name : "TDevMakeFrontend") {}
+ KDevMakeFrontend(const KDevPluginInfo *info, TQObject *parent=0, const char *name=0 )
+ :KDevPlugin(info, parent, name ? name : "KDevMakeFrontend") {}
/**@return The widget where the make output is shown.*/
virtual TQWidget* widget() { return 0L; }
diff --git a/lib/interfaces/extensions/tdevquickopen.h b/lib/interfaces/extensions/kdevquickopen.h
index e1fd2f65..91dce7ca 100644
--- a/lib/interfaces/extensions/tdevquickopen.h
+++ b/lib/interfaces/extensions/kdevquickopen.h
@@ -16,14 +16,14 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef TDEVQUICKOPEN_H
-#define TDEVQUICKOPEN_H
+#ifndef KDEVQUICKOPEN_H
+#define KDEVQUICKOPEN_H
-#include <tdevplugin.h>
+#include <kdevplugin.h>
#include <kurl.h>
/**
-@file tdevquickopen.h
+@file kdevquickopen.h
Source formatter interface.
*/
@@ -39,10 +39,10 @@ if (qo) {
// fail
}
@endcode
-@sa @ref TDevPlugin::extension method documentation.
+@sa @ref KDevPlugin::extension method documentation.
@sa @ref whatisextension and @ref creatingextension sections of Platform API documentation.
*/
-class KDevQuickOpen : public TDevPlugin
+class KDevQuickOpen : public KDevPlugin
{
public:
/**Constructor.
@@ -51,11 +51,11 @@ public:
plugin information in various places like "about application" dialog, plugin selector
dialog, etc. Plugin does not take ownership on info object, also its lifetime should
be equal to the lifetime of the plugin.
- @param parent The parent object for the plugin. Parent object must implement @ref TDevApi
+ @param parent The parent object for the plugin. Parent object must implement @ref KDevApi
interface. Otherwise the plugin will not be constructed.
@param name The internal name which identifies the plugin.*/
- KDevQuickOpen(const TDevPluginInfo *info, TQObject* parent, const char* name)
- :TDevPlugin(info, parent, name) {}
+ KDevQuickOpen(const KDevPluginInfo *info, TQObject* parent, const char* name)
+ :KDevPlugin(info, parent, name) {}
/**Shows the file selection dialog.
@param text A list of urls to open.*/
@@ -81,14 +81,14 @@ public:
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef TDEVQUICKOPEN_H
-#define TDEVQUICKOPEN_H
+#ifndef KDEVQUICKOPEN_H
+#define KDEVQUICKOPEN_H
-#include <tdevplugin.h>
+#include <kdevplugin.h>
#include <kurl.h>
/**
-@file tdevquickopen.h
+@file kdevquickopen.h
Source formatter interface.
*/
@@ -104,10 +104,10 @@ if (qo) {
// fail
}
@endcode
-@sa @ref TDevPlugin::extension method documentation.
+@sa @ref KDevPlugin::extension method documentation.
@sa @ref whatisextension and @ref creatingextension sections of Platform API documentation.
*/
-class KDevQuickOpen : public TDevPlugin
+class KDevQuickOpen : public KDevPlugin
{
public:
/**Constructor.
@@ -116,11 +116,11 @@ public:
plugin information in various places like "about application" dialog, plugin selector
dialog, etc. Plugin does not take ownership on info object, also its lifetime should
be equal to the lifetime of the plugin.
- @param parent The parent object for the plugin. Parent object must implement @ref TDevApi
+ @param parent The parent object for the plugin. Parent object must implement @ref KDevApi
interface. Otherwise the plugin will not be constructed.
@param name The internal name which identifies the plugin.*/
- KDevQuickOpen(const TDevPluginInfo *info, TQObject* parent, const char* name)
- :TDevPlugin(info, parent, name) {}
+ KDevQuickOpen(const KDevPluginInfo *info, TQObject* parent, const char* name)
+ :KDevPlugin(info, parent, name) {}
/**Shows the file selection dialog.
@param text A list of urls to open.*/
diff --git a/lib/interfaces/extensions/tdevsourceformatter.h b/lib/interfaces/extensions/kdevsourceformatter.h
index 3403a5d2..c4a380cf 100644
--- a/lib/interfaces/extensions/tdevsourceformatter.h
+++ b/lib/interfaces/extensions/kdevsourceformatter.h
@@ -16,13 +16,13 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef TDEVSOURCEFORMATTER_H
-#define TDEVSOURCEFORMATTER_H
+#ifndef KDEVSOURCEFORMATTER_H
+#define KDEVSOURCEFORMATTER_H
-#include <tdevplugin.h>
+#include <kdevplugin.h>
/**
-@file tdevsourceformatter.h
+@file kdevsourceformatter.h
Source formatter interface.
*/
@@ -39,10 +39,10 @@ if (sf) {
// fail
}
@endcode
-@sa @ref TDevPlugin::extension method documentation.
+@sa @ref KDevPlugin::extension method documentation.
@sa @ref whatisextension and @ref creatingextension sections of Platform API documentation.
*/
-class KDevSourceFormatter : public TDevPlugin
+class KDevSourceFormatter : public KDevPlugin
{
public:
/**Constructor.
@@ -51,11 +51,11 @@ public:
plugin information in various places like "about application" dialog, plugin selector
dialog, etc. Plugin does not take ownership on info object, also its lifetime should
be equal to the lifetime of the plugin.
- @param parent The parent object for the plugin. Parent object must implement @ref TDevApi
+ @param parent The parent object for the plugin. Parent object must implement @ref KDevApi
interface. Otherwise the plugin will not be constructed.
@param name The internal name which identifies the plugin.*/
- KDevSourceFormatter(const TDevPluginInfo *info, TQObject* parent, const char* name)
- :TDevPlugin(info, parent, name) {}
+ KDevSourceFormatter(const KDevPluginInfo *info, TQObject* parent, const char* name)
+ :KDevPlugin(info, parent, name) {}
/**Formats the source.
@param text A string with a code.
diff --git a/lib/interfaces/extensions/tdevversioncontrol.h b/lib/interfaces/extensions/kdevversioncontrol.h
index d796e31f..a19c6275 100644
--- a/lib/interfaces/extensions/tdevversioncontrol.h
+++ b/lib/interfaces/extensions/kdevversioncontrol.h
@@ -20,8 +20,8 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef TDEVVERSIONCONTROL_H
-#define TDEVVERSIONCONTROL_H
+#ifndef KDEVVERSIONCONTROL_H
+#define KDEVVERSIONCONTROL_H
#include <tqobject.h>
#include <tqstring.h>
@@ -29,10 +29,10 @@
#include <tqmap.h>
#include <tqvaluelist.h>
-#include <tdevplugin.h>
+#include <kdevplugin.h>
/**
-@file tdevversioncontrol.h
+@file kdevversioncontrol.h
Version control system interface and utility classes.
*/
@@ -112,7 +112,7 @@ This is a type definition: @code TQMap<TQString,VCSFileInfo> VCSFileInfoMap; @en
*/
typedef TQMap<TQString,VCSFileInfo> VCSFileInfoMap;
-class TDevVCSFileInfoProvider;
+class KDevVCSFileInfoProvider;
/**
@@ -123,16 +123,16 @@ VCS support plugins should implement this interface.
Instances that implement this interface are available through extension architecture:
@code
-TDevVersionControl *vcs = extension<TDevVersionControl>("TDevelop/VersionControl");
+KDevVersionControl *vcs = extension<KDevVersionControl>("TDevelop/VersionControl");
if (vcs) {
// do something
} else {
// fail
}
@endcode
-@sa TDevPlugin::extension method documentation.
+@sa KDevPlugin::extension method documentation.
*/
-class TDevVersionControl: public TDevPlugin
+class KDevVersionControl: public KDevPlugin
{
Q_OBJECT
@@ -144,11 +144,11 @@ public:
plugin information in various places like "about application" dialog, plugin selector
dialog, etc. Plugin does not take ownership on info object, also its lifetime should
be equal to the lifetime of the plugin.
- @param parent The parent object for the plugin. Parent object must implement @ref TDevApi
+ @param parent The parent object for the plugin. Parent object must implement @ref KDevApi
interface. Otherwise the plugin will not be constructed.
@param name The internal name which identifies the plugin.*/
- TDevVersionControl(const TDevPluginInfo *info, TQObject *parent, const char *name )
- :TDevPlugin(info, parent, name ) {}
+ KDevVersionControl(const KDevPluginInfo *info, TQObject *parent, const char *name )
+ :KDevPlugin(info, parent, name ) {}
/**Creates a new project in the passed path @p dir. This should instantiate
VCS infrastructure and import a project into the VCS in that directory.
@@ -161,7 +161,7 @@ public:
virtual bool fetchFromRepository() = 0;
/**@return The file info provider for this version control (0 if none is available).*/
- virtual TDevVCSFileInfoProvider *fileInfoProvider() const = 0;
+ virtual KDevVCSFileInfoProvider *fileInfoProvider() const = 0;
/**Checks if the directory is valid for this version control (for example
CVS may check for the presence of "<dirPath>/CVS/" subdir and something else)
@@ -182,7 +182,7 @@ signals:
/**
Basic interface for providing info on file registered in a version control repository repository.
*/
-class TDevVCSFileInfoProvider: public TQObject
+class KDevVCSFileInfoProvider: public TQObject
{
Q_OBJECT
@@ -190,7 +190,7 @@ public:
/**Constructor.
@param parent The parent VCS plugin.
@param name The name of a provider object.*/
- TDevVCSFileInfoProvider(TDevVersionControl *parent, const char *name)
+ KDevVCSFileInfoProvider(KDevVersionControl *parent, const char *name)
: TQObject( parent, name ), m_owner(parent) {}
/**Gets the status for local files in the specified directory:
@@ -226,14 +226,14 @@ signals:
protected:
/**@return The version control which owns this provider.*/
- TDevVersionControl *owner() const { return m_owner; }
+ KDevVersionControl *owner() const { return m_owner; }
private:
- TDevVersionControl *m_owner;
+ KDevVersionControl *m_owner;
private:
- TDevVCSFileInfoProvider( const TDevVCSFileInfoProvider & );
- TDevVCSFileInfoProvider &operator=( const TDevVCSFileInfoProvider & );
+ KDevVCSFileInfoProvider( const KDevVCSFileInfoProvider & );
+ KDevVCSFileInfoProvider &operator=( const KDevVCSFileInfoProvider & );
};
#endif
diff --git a/lib/interfaces/extensions/tdevappfrontend.cpp b/lib/interfaces/extensions/tdevappfrontend.cpp
deleted file mode 100644
index 4f7c52a7..00000000
--- a/lib/interfaces/extensions/tdevappfrontend.cpp
+++ /dev/null
@@ -1,2 +0,0 @@
-#include "tdevappfrontend.h"
-#include "tdevappfrontend.moc"
diff --git a/lib/interfaces/extensions/tdevmakefrontend.cpp b/lib/interfaces/extensions/tdevmakefrontend.cpp
deleted file mode 100644
index 140d074d..00000000
--- a/lib/interfaces/extensions/tdevmakefrontend.cpp
+++ /dev/null
@@ -1,2 +0,0 @@
-#include "tdevmakefrontend.h"
-#include "tdevmakefrontend.moc"
diff --git a/lib/interfaces/extensions/tdevcreatefile.h b/lib/interfaces/extensions/kdevcreatefile.h
index b1148e94..35b98d19 100644
--- a/lib/interfaces/extensions/tdevcreatefile.h
+++ b/lib/interfaces/extensions/kdevcreatefile.h
@@ -17,15 +17,15 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef TDEVCREATEFILE_H
-#define TDEVCREATEFILE_H
+#ifndef KDEVCREATEFILE_H
+#define KDEVCREATEFILE_H
#include <tqstring.h>
-#include <tdevplugin.h>
+#include <kdevplugin.h>
/**
-@file tdevcreatefile.h
+@file kdevcreatefile.h
File creation facility interface.
*/
@@ -36,20 +36,20 @@ An abstract class for all extensions that are responsible for file creation.
Instances that implement this interface are available through extension architecture:
@code
-TDevCreateFile *cf = extension<TDevCreateFile>("TDevelop/CreateFile");
+KDevCreateFile *cf = extension<KDevCreateFile>("TDevelop/CreateFile");
if (cf) {
// do something
} else {
// fail
}
@endcode
-@sa TDevPlugin::extension method documentation.
+@sa KDevPlugin::extension method documentation.
*/
-class TDevCreateFile : public TDevPlugin
+class KDevCreateFile : public KDevPlugin
{
public:
/**File created with @ref TDevCreateFile implementation.*/
class CreatedFile {
public:
@@ -119,11 +119,11 @@ public:
plugin information in various places like "about application" dialog, plugin selector
dialog, etc. Plugin does not take ownership on info object, also its lifetime should
be equal to the lifetime of the plugin.
- @param parent The parent object for the plugin. Parent object must implement @ref TDevApi
+ @param parent The parent object for the plugin. Parent object must implement @ref KDevApi
interface. Otherwise the plugin will not be constructed.
@param name The internal name which identifies the plugin.*/
- TDevCreateFile(const TDevPluginInfo *info, TQObject * parent = 0, const char * name = 0)
- :TDevPlugin(info, parent, name) {}
+ KDevCreateFile(const KDevPluginInfo *info, TQObject * parent = 0, const char * name = 0)
+ :KDevPlugin(info, parent, name) {}
/**Creates a new file, within or without the project.
Supply as much information as you know. Leave what you don't know as TQString().
@@ -36,20 +36,20 @@ An abstract class for all extensions that are responsible for file creation.
{
public:
- /**File created with @ref TDevCreateFile implementation.*/
+ /**File created with @ref KDevCreateFile implementation.*/
class CreatedFile {
public: